@@ -6,8 +6,9 @@
 # Description:
 import re
 import jionlp as jio
+from math import ceil
 from datetime import datetime
-from nlp_time.pre import text_pre
+from nlp_time.utils import text_pre, around_today
 from dateutil.relativedelta import relativedelta
 from typing import Union
 
@@ -27,13 +28,13 @@ def get_time(text: str, tend_future=True):
         if "inf" in time_tuple[0]:
             t1 = None
         else:
-            t1 = datetime.strptime(time_tuple[0], time_format)
+            t1 = datetime.strptime(time_tuple[0], TIME_FORMAT)
         if "inf" in time_tuple[1]:
             t2 = None
         else:
-            t2 = datetime.strptime(time_tuple[1], time_format)
+            t2 = datetime.strptime(time_tuple[1], TIME_FORMAT)
         if time_dict.get("type", "") == "time_point":
-            if re.findall(re_week, text):
+            if re.findall(RE_WEEK, text):
                 if tend_future:
                     if t1 and t1 < now:
                         t1 = t1 + relativedelta(weeks=1)
@@ -43,9 +44,9 @@ def get_time(text: str, tend_future=True):
                         t1 = t1 - relativedelta(weeks=1)
                         t2 = t2 - relativedelta(weeks=1)
         if isinstance(t1, datetime):
-            t1 = t1.strftime(time_format)
+            t1 = t1.strftime(TIME_FORMAT)
         if isinstance(t2, datetime):
-            t2 = t2.strftime(time_format)
+            t2 = t2.strftime(TIME_FORMAT)
         time_tuple = (t1, t2)
     except ValueError as _:
         pass
@@ -55,22 +56,24 @@ def get_time(text: str, tend_future=True):
 def get_text(time: Union[datetime, str, int]):
     now = datetime.now()
     if isinstance(time, str):
-        time = datetime.strptime(time, time_format)
+        time = datetime.strptime(time, TIME_FORMAT)
     elif isinstance(time, int):
         time = datetime.fromtimestamp(time)
     duration = now - time
+    today_zero = now - relativedelta(hour=0, minute=0, second=0, microsecond=0)
+    zero_duration = today_zero - time
+    days_span_today_zero = ceil(zero_duration.days + zero_duration.seconds / SECONDS_ONE_DAY)
     reply = []
     if not duration.days:
         if duration.seconds < 60:
             return f"{duration.seconds}秒前"
         if duration.seconds < 600:
             return f"{int(duration.seconds / 60)}分钟前"
-        day_span = now.day - time.day
-        if day_span:
-            reply.append({2: "前天", 1: "昨天", -1: "明天", -2: "后天"}.get(day_span, ""))
+        if days_span_today_zero:
+            reply.append(around_today(days_span_today_zero))
     else:
-        if -2 <= duration.days <= 2:
-            reply.append({2: "前天", 1: "昨天", -1: "明天", -2: "后天"}.get(duration.days, ""))
+        if -2 <= days_span_today_zero <= 2:
+            reply.append(around_today(days_span_today_zero))
         elif time.year != now.year:
             month_year = now.year - time.year
             if month_year:
@@ -78,12 +81,20 @@ def get_text(time: Union[datetime, str, int]):
                 reply.append(_m.get(month_year, time.year))
             reply.append(f"{time.month}月")
             reply.append(f"{time.day}号")
-        else:
+        elif time.month != now.month:
             month_span = now.month - time.month
             if month_span:
                 _m = {1: "上个", -1: "下个"}
                 reply.append(f"{_m.get(month_span, time.month)}月")
             reply.append(f"{time.day}号")
+        else:
+            week_span = time.day - (now.day - now.weekday())
+            if -7 <= week_span < 0:
+                reply.append(f"上周{week_span + 7 + 1}")
+            elif 7 <= week_span < 14:
+                reply.append(f"下周{ week_span - 7 + 1}")
+            else:
+                reply.append(f"{time.day}号")
     if 0 <= time.hour < 6:
         reply.append("凌晨")
     elif 6 <= time.hour < 8:
@@ -102,6 +113,8 @@ def get_text(time: Union[datetime, str, int]):
     return "".join(reply)
 
 
-week_day_strs = "一二三四五六日天末"
-re_week = rf"(?<!这个)(?<!这|本)(?:周|星期)([\d{week_day_strs}])"
-time_format = "%Y-%m-%d %H:%M:%S"
+SECONDS_ONE_DAY = 60 * 60 * 24
+WEEK_DAY_DICT = {1: "一", 2: "二", 3: "三", 4: "四", 5: "五", 6: "日", 7: "天"}
+WEEK_DAY_STRS = "一二三四五六日天末"
+RE_WEEK = rf"(?<!这个)(?<!这|本)(?:周|星期)([\d{WEEK_DAY_STRS}])"
+TIME_FORMAT = "%Y-%m-%d %H:%M:%S"
